@@ -525,24 +525,26 @@ static gboolean cbBus(GstBus *bus,
     {
         case GST_MESSAGE_WARNING:
         {
-            GError *err;
-            gchar *debug;
+            GError *err = NULL;
+            gchar *debug = NULL;
 
-            gst_message_parse_error (message, &err, &debug);
+            gst_message_parse_warning (message, &err, &debug);
             ULOG_WARN("%s() - Warning: %s", G_STRFUNC, err->message);
-            g_error_free (err);
+            if (err)
+                g_error_free (err);
             g_free (debug);
             break;
         }
 
         case GST_MESSAGE_ERROR: 
         {
-            GError *err;
-            gchar *debug;
+            GError *err = NULL;
+            gchar *debug = NULL;
 
             gst_message_parse_error (message, &err, &debug);
             ULOG_ERR("%s() - Error: %s", G_STRFUNC, err->message);
-            g_error_free (err);
+            if (err)
+                g_error_free (err);
             g_free (debug);
             /* break; */
             /* flow through to eos */
@@ -1024,9 +1026,9 @@ static void cbEmailing(GtkWidget* widget, AppData *data)
 
     g_assert(NULL != data);
     
-    if (g_file_test(getFileName(data), G_FILE_TEST_EXISTS))
+    if (g_file_test(data->openFileName, G_FILE_TEST_EXISTS))
     {
-        file = file2uri(getFileName(data));
+        file = file2uri(data->openFileName);
         ULOG_INFO("Emailing: %s", file);
         list = g_slist_append(list, file);
         result = libmodest_dbus_client_compose_mail(data->osso,
